# Qualtrics SDK for Node

## Introduction

The purpose of this library is to provide a Node client to the Qualtrics public facing API.

## Getting started

### Installation

#### Via private Qualtrics Github repository

Must have access to the repository and have access setup (e.g. SSH) in your GitHub account.

- `npm install --save git+ssh://git@github.com:Qualtrics/qualtrics-sdk-node.git`

### Usage

First find your data center and API token:

- Data center: https://api.qualtrics.com/docs/root-url#how-to-find-your-api-hostname
- API token: https://api.qualtrics.com/docs/finding-qualtrics-ids

The SDK supports instantiation by default. This method is recommended if multiple datacenters and tokens are needed simultaneously:

```javascript
const QualtricsSdk = require('qualtrics-sdk');

const qualtrics = new QualtricsSdk({
  dataCenter: '...',
  apiToken: '...',
});

qualtrics.surveys.listSurveys()
  .then((response) => console.log(response));
```

API calls are namespaced to their respective resources. User API calls can be found at `qualtrics.users`, Survey API calls can be found at `qualtrics.surveys`, etc.

However, Target Audience calls are an exception. Because some of the resource names conflict with Insight Platform calls, they have been namespaced to their sub-resources under their top-level resource, `directories.`

For example, Target Audience Contact API calls can be found at `qualtrics.directories.contacts`, Target Audience Mailing List API calls can be found at `qualtrics.directories.mailingLists`, etc.

## Useful links

- Qualtrics API documentation: https://api.qualtrics.com/

## Contributing

Refer to the [contribution guidelines](CONTRIBUTING.md).

## Legal

This project is licensed under the Apache License version 2.0. Please refer to the [license](LICENSE.md) for usage info.

## Warning

Do not expose your API token! This project is for server-side usage only.
