const Config = require('./util/config');
const Http = require('./util/http');
const autoBind = require('./util/autobind');
const Distributions = require('./resources/distributions');
const ResponseExports = require('./resources/responseExports');
const ResponseImports = require('./resources/responseImports');
const Responses = require('./resources/responses');
const Surveys = require('./resources/surveys');
const Users = require('./resources/users');
const Organizations = require('./resources/organizations');
const Divisions = require('./resources/divisions');
const Groups = require('./resources/groups');
const EventSubscriptions = require('./resources/eventsubscriptions');
const Graphics = require('./resources/graphics');
const LibraryMessages = require('./resources/libraryMessages');
const MailingLists = require('./resources/mailingLists');
const Directories = require('./resources/directories');

class QualtricsSdk {
  constructor({dataCenter, apiToken, http} = {}) {
    this.configure({dataCenter, apiToken, http});
    autoBind(this);
  }

  configure({dataCenter, apiToken, http = null} = {}) {
    this.config = new Config({dataCenter, apiToken});
    if (!http) {
      http = new Http(this.config);
    }
    this.distributions = new Distributions(http);
    this.responseExports = new ResponseExports(http);
    this.responseImports = new ResponseImports(http);
    this.responses = new Responses(http);
    this.surveys = new Surveys(http);
    this.users = new Users(http);
    this.organizations = new Organizations(http);
    this.divisions = new Divisions(http);
    this.eventSubscriptions = new EventSubscriptions(http);
    this.graphics = new Graphics(http);
    this.libraryMessages = new LibraryMessages(http);
    this.mailingLists = new MailingLists(http);
    this.groups = new Groups(http);
    this.directories = {
      contacts: new Directories.Contacts(http),
      mailingLists: new Directories.DirectoryMailingLists(http),
      frequencyRules: new Directories.FrequencyRules(http),
      samples: new Directories.Samples(http),
      transactionBatches: new Directories.TransactionBatches(http),
    };
  }
}

module.exports = QualtricsSdk;
