const uri = require('./uriGenerators');
const autoBind = require('../../util/autobind');

/**
 * DirectoryMailingLists
 */
class DirectoryMailingLists {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {string} directoryId
   * @param {Object} queryParams
   * @return {Promise}
   */
  listMailingLists(directoryId, queryParams) {
    return this.http.get(uri._mailingListsUri(directoryId, ''), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @return {Promise}
   */
  getMailingList(directoryId, mailingListId) {
    return this.http.get(uri._mailingListsUri(directoryId, mailingListId));
  }

  /**
   * @param {string} directoryId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createMailingList(directoryId, bodyParams) {
    return this.http.post(uri._mailingListsUri(directoryId, ''), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateMailingList(directoryId, mailingListId, bodyParams) {
    return this.http.put(uri._mailingListsUri(directoryId, mailingListId), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @return {Promise}
   */
  deleteMailingList(directoryId, mailingListId) {
    return this.http.delete(uri._mailingListsUri(directoryId, mailingListId));
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  importMailingListContactsWithTransactions(directoryId, mailingListId, bodyParams) {
    return this.http.post(uri._transactionContactsUri(directoryId, mailingListId), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @param {string} importId
   * @return {Promise}
   */
  getTransactionContactsImportStatus(directoryId, mailingListId, importId) {
    return this.http.get(uri._transactionContactsUri(directoryId, mailingListId, importId));
  }

  /**
   * @param {string} directoryId
   * @param {string} mailingListId
   * @param {string} importId
   * @return {Promise}
   */
  getTransactionContactsImportSummary(directoryId, mailingListId, importId) {
    return this.http.get(`${uri._transactionContactsUri(directoryId, mailingListId, importId)}/summary`);
  }
}

module.exports = DirectoryMailingLists;
