const uri = require('./uriGenerators');
const autoBind = require('../../util/autobind');

/**
 * Samples
 */
class Samples {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {string} directoryId
   * @param {Object} queryParams
   * @return {Promise}
   */
  listSamples(directoryId, queryParams) {
    return this.http.get(uri._samplesUri(directoryId, ''), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleId
   * @return {Promise}
   */
  getSample(directoryId, sampleId) {
    return this.http.get(uri._samplesUri(directoryId, sampleId));
  }

  /**
   * @param {string} directoryId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  performSample(directoryId, bodyParams) {
    return this.http.post(uri._samplesUri(directoryId, ''), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateSample(directoryId, sampleId, bodyParams) {
    return this.http.put(uri._samplesUri(directoryId, sampleId), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleId
   * @return {Promise}
   */
  deleteSample(directoryId, sampleId) {
    return this.http.delete(uri._samplesUri(directoryId, sampleId));
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleId
   * @return {Promise}
   */
  getSampleContacts(directoryId, sampleId) {
    return this.http.get(uri._samplesContactsUri(directoryId, sampleId));
  }

  /**
   * @param {string} directoryId
   * @param {string} progressId
   * @return {Promise}
   */
  getCreateSampleProgress(directoryId, progressId) {
    return this.http.get(uri._samplesProgressUri(directoryId, progressId));
  }

  /**
   * @param {string} directoryId
   * @param {Object} queryParams
   * @return {Promise}
   */
  listSampleDefinitions(directoryId, queryParams) {
    return this.http.get(uri._samplesDefinitionsUri(directoryId, ''), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleDefinitionId
   * @param {Object} queryParams
   * @return {Promise}
   */
  getSampleDefinition(directoryId, sampleDefinitionId, queryParams) {
    return this.http.get(uri._samplesDefinitionsUri(directoryId, sampleDefinitionId), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createSampleDefinition(directoryId, bodyParams) {
    return this.http.post(uri._samplesDefinitionsUri(directoryId, ''), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleDefinitionId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateSampleDefinition(directoryId, sampleDefinitionId, bodyParams) {
    return this.http.put(uri._samplesDefinitionsUri(directoryId, sampleDefinitionId), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} sampleDefinitionId
   * @return {Promise}
   */
  deleteSampleDefinition(directoryId, sampleDefinitionId) {
    return this.http.delete(uri._samplesDefinitionsUri(directoryId, sampleDefinitionId));
  }
}

module.exports = Samples;
