const uri = require('./uriGenerators');
const autoBind = require('../../util/autobind');

/**
 * TransactionBatches
 */
class TransactionBatches {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {string} directoryId
   * @param {Object} queryParams
   * @return {Promise}
   */
  getTransactionBatchesInDirectory(directoryId, queryParams) {
    return this.http.get(uri._transactionBatchesUri(directoryId, ''), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @param {Object} queryParams
   * @return {Promise}
   */
  getTransactionsInABatch(directoryId, batchId, queryParams) {
    return this.http.get(uri._transactionBatchesTransactionUri(directoryId, batchId, ''), queryParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @return {Promise}
   */
  getTransactionBatch(directoryId, batchId) {
    return this.http.get(uri._transactionBatchesUri(directoryId, batchId));
  }

  /**
   * @param {string} directoryId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createTransactionBatch(directoryId, bodyParams) {
    return this.http.post(uri._transactionBatchesUri(directoryId, ''), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateTransactionBatch(directoryId, batchId, bodyParams) {
    return this.http.put(uri._transactionBatchesUri(directoryId, batchId), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @return {Promise}
   */
  deleteTransactionBatch(directoryId, batchId) {
    return this.http.delete(uri._transactionBatchesUri(directoryId, batchId));
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  addTransactionsToABatch(directoryId, batchId, bodyParams) {
    return this.http.post(uri._transactionBatchesTransactionUri(directoryId, batchId, ''), bodyParams);
  }

  /**
   * @param {string} directoryId
   * @param {string} batchId
   * @param {string} transactionId
   * @return {Promise}
   */
  removeTransactionFromABatch(directoryId, batchId, transactionId) {
    return this.http.delete(uri._transactionBatchesTransactionUri(directoryId, batchId, transactionId));
  }
}

module.exports = TransactionBatches;
