const autoBind = require('../util/autobind');
const querystring = require('querystring');

/**
 * Distributions
 */
class Distributions {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {string} distributionId
   * @return {Promise}
   */
  deleteDistribution(distributionId) {
    return this.http.delete(_distributionsUri(distributionId));
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createSurveyDistribution(bodyParams) {
    return this.http.post(_distributionsUri(''), bodyParams);
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createTransactionBatchSurveyDistribution(bodyParams) {
    return this.http.post(_distributionsUri(), bodyParams);
  }

  /**
   * @param {string} parentDistributionId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createReminderDistribution(parentDistributionId, bodyParams) {
    return this.http.post(_remindersUri(parentDistributionId), bodyParams);
  }

  /**
   * @param {string} parentDistributionId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createThankYouDistribution(parentDistributionId, bodyParams) {
    return this.http.post(_thankYousUri(parentDistributionId), bodyParams);
  }

  /**
   * @param {Object} queryParams
   * @return {Promise}
   */
  listDistributions(queryParams) {
    return this.http.get(_distributionsUri(), queryParams);
  }

  /**
   * @param {string} distributionId
   * @param {Object} queryParams
   * @return {Promise}
   */
  getDistribution(distributionId, queryParams) {
    return this.http.get(_distributionsUri(distributionId), queryParams);
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  generateDistributionLinks(bodyParams) {
    return this.http.post(_distributionsUri(''), bodyParams);
  }

  /**
   * @param {string} distributionId
   * @param {Object} queryParams
   * @return {Promise}
   */
  listDistributionLinks(distributionId, queryParams) {
    return this.http.get(_linksUri(distributionId), queryParams);
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  sendEmailToMailingList(bodyParams) {
    return this.http.post(_distributionsUri(), bodyParams);
  }

  /**
   * @param {Object} queryParams
   * @param {Array} distributions
   * @return {Promise}
   */
  getAllDistributions(queryParams, distributions = []) {
    return this.listDistributions(queryParams)
      .then((response) => {
        distributions = distributions.concat(response.result.elements);
        if (response.result.nextPage) {
          queryParams.offset = querystring.parse(
            response.result.nextPage.split('?')[1]);
          return this.getAllDistributions(queryParams, distributions);
        }
        return distributions;
      });
  }
}

function _distributionsUri(distributionId = '') {
  return `/distributions/${distributionId}`;
}

function _remindersUri(distributionId) {
  return `${_distributionsUri(distributionId)}/reminders`;
}

function _thankYousUri(distributionId) {
  return `${_distributionsUri(distributionId)}/thankyous`;
}

function _linksUri(distributionId) {
  return `${_distributionsUri(distributionId)}/links`;
}

module.exports = Distributions;

