const querystring = require('querystring');
const autoBind = require('../util/autobind');

/**
 * EventSubscriptions
 */
class EventSubscriptions {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {Object} queryParams
   * @param {Array} subscriptions
   * @return {Promise}
   */
  getAllSubscriptions(queryParams, subscriptions = []) {
    return this.listSubscriptions(queryParams)
      .then((response) => {
        subscriptions = subscriptions.concat(response.result.elements);
        if (response.result.nextPage) {
          queryParams.offset = querystring.parse(
            response.result.nextPage.split('?')[1]);
          return this.getAllSubscriptions(queryParams, subscriptions);
        }
        return subscriptions;
      });
  }

  /**
   * @param {Object} queryParams
   * @return {Promise}
   */
  listSubscriptions(queryParams) {
    return this.http.get(_eventSubscriptionsUri(), queryParams);
  }

  /**
   * @param {string} subscriptionId
   * @return {Promise}
   */
  getSubscription(subscriptionId) {
    return this.http.get(_eventSubscriptionsUri(subscriptionId));
  }

  /**
   * @param {string} subscriptionId
   * @return {Promise}
   */
  deleteSubscription(subscriptionId) {
    return this.http.delete(_eventSubscriptionsUri(subscriptionId));
  }

  /**
   * @return {Promise}
   */
  deleteSubscriptions() {
    return this.http.delete(_eventSubscriptionsUri());
  }


  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createSubscription(bodyParams) {
    return this.http.post(_eventSubscriptionsUri(), bodyParams);
  }
}

function _eventSubscriptionsUri(subscriptionId = '') {
  return `/eventsubscriptions/${subscriptionId}`;
}

module.exports = EventSubscriptions;
