const FormData = require('form-data');
const path = require('path');
const autoBind = require('../util/autobind');

/**
 * Graphics
 */
class Graphics {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param  {string} libraryId
   * @param  {Buffer} fileStream
   * @param  {Object} bodyParams
   * @return {Promise}
   */
  uploadGraphic(libraryId, fileStream, bodyParams) {
    const formData = new FormData();
    let fileExtensionNoDot = path.extname(fileStream.path).substring(1);
    // TODO - add unit test validation on the file extension

    if (fileExtensionNoDot === 'jpg') {
      fileExtensionNoDot = 'jpeg';
    }

    formData.append(
      'file',
      fileStream,
      {contentType: `image/${fileExtensionNoDot}`}
    );

    Object.keys(bodyParams).forEach((key) => {
      formData.append(key, bodyParams[key]);
    });

    const options = {
      method: 'POST',
      body: formData,
    };

    return this.http.fetchJsonWithAuth(_graphicsUri(libraryId), options);
  }

  /**
   * @param  {string} libraryId
   * @param  {Object} bodyParams
   * @return {Promise}
   */
  uploadGraphicFromUrl(libraryId, bodyParams) {
    const formData = new FormData();

    Object.keys(bodyParams).forEach((key) => {
      formData.append(key, bodyParams[key]);
    });

    const options = {
      method: 'POST',
      body: formData,
    };

    return this.http.fetchJsonWithAuth(_graphicsUri(libraryId), options);
  }

  /**
   * @param  {string} libraryId
   * @param  {string} graphicId
   * @return {Promise}
   */
  deleteGraphic(libraryId, graphicId) {
    return this.http.delete(_graphicsUri(libraryId, graphicId));
  }
}

function _graphicsUri(libraryId = '', graphicId = '') {
  return `/libraries/${libraryId}/graphics/${graphicId}`;
}

module.exports = Graphics;
