const querystring = require('querystring');
const autoBind = require('../util/autobind');

/**
 * Groups
 */
class Groups {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * Get groups with pagination handling.
   * @param {object} queryParams
   * @param {Array} groups
   * @return {Promise}
   */
  getAllGroups(queryParams, groups = []) {
    return this.listGroups(queryParams)
      .then((response) => {
        groups = groups.concat(response.result.elements);
        if (response.result.nextPage) {
          const offset = querystring.parse(
            response.result.nextPage.split('?')[1]);
          queryParams.offset = offset;
          return this.getAllGroups(queryParams, groups);
        }
        return groups;
      });
  }

  /**
   * @param {Object} queryParams
   * @return {Promise}
   */
  listGroups(queryParams) {
    return this.http.get(_groupsUri(), queryParams);
  }

  /**
   * @param {string} groupId
   * @return {Promise}
   */
  getGroup(groupId) {
    return this.http.get(_groupsUri(groupId));
  }

  /**
   * @param {string} groupId
   * @return {Promise}
   */
  deleteGroup(groupId) {
    return this.http.delete(_groupsUri(groupId));
  }

  /**
   * @param {string} groupId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateGroup(groupId, bodyParams) {
    return this.http.put(_groupsUri(groupId), bodyParams);
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createGroup(bodyParams) {
    return this.http.post(_groupsUri(), bodyParams);
  }

  /**
   * @param {String} groupId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  addUserToGroup(groupId, bodyParams) {
    return this.http.post(_groupsUriWithMembers(groupId), bodyParams);
  }

  /**
   * @param {string} groupId
   * @param {string} userId
   * @return {Promise}
   */
  removeUserFromGroup(groupId, userId) {
    return this.http.delete(_groupsUriWithMembers(groupId, userId));
  }
}

function _groupsUri(groupId = '') {
  return `/groups/${groupId}`;
}

function _groupsUriWithMembers(groupId, userId = '') {
  return `/groups/${groupId}/members/${userId}`;
}

module.exports = Groups;
