const autoBind = require('../util/autobind');

/**
 * LibraryMessages
 */
class LibraryMessages {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {string} libraryId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createLibraryMessage(libraryId, bodyParams) {
    return this.http.post(_libraryMessageUri(libraryId), bodyParams);
  }

  /**
   * @param {string} libraryId
   * @param {string} libraryMessageId
   * @return {Promise}
   */
  getLibraryMessage(libraryId, libraryMessageId) {
    return this.http.get(_libraryMessageUri(libraryId, libraryMessageId));
  }

  /**
   * @param {string} libraryId
   * @param {Object} queryParams
   * @return {Promise}
   */
  getLibraryMessages(libraryId, queryParams) {
    return this.http.get(_libraryMessageUri(libraryId), queryParams);
  }

  /**
   * @param {string} libraryId
   * @param {string} libraryMessageId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateLibraryMessage(libraryId, libraryMessageId, bodyParams) {
    return this.http.put(_libraryMessageUri(libraryId, libraryMessageId), bodyParams);
  }

  /**
   * @param {string} libraryId
   * @param {string} libraryMessageId
   * @return {Promise}
   */
  deleteLibraryMessage(libraryId, libraryMessageId) {
    return this.http.delete(_libraryMessageUri(libraryId, libraryMessageId));
  }
}

function _libraryMessageUri(libraryId, libraryMessageId = '') {
  return `/libraries/${libraryId}/messages/${libraryMessageId}`;
}

module.exports = LibraryMessages;
