const FormData = require('form-data');
const autoBind = require('../util/autobind');

/**
 * ResponseImports
 */
class ResponseImports {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {Buffer} fileStream
   * @param {Object} bodyParams
   * @return {Promise}
   */
  importResponses(fileStream, bodyParams) {
    const formData = new FormData();
    formData.append('file', fileStream, {contentType: 'text/csv'});
    Object.keys(bodyParams).forEach((key) => {
      formData.append(key, bodyParams[key]);
    });
    return this.http.fetchJsonWithAuth(_responseImportsUri(), {
      method: 'POST',
      body: formData,
    });
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  importResponsesFromUrl(bodyParams) {
    return this.http.post(_responseImportsUri(), bodyParams);
  }

  /**
   * @param {string} importId
   * @return {Promise}
   */
  getResponseImportProgress(importId) {
    return this.http.get(_responseImportsUri(importId));
  }
}

function _responseImportsUri(importId = '') {
  return `/responseimports/${importId}`;
}

module.exports = ResponseImports;
