const autoBind = require('../util/autobind');

/**
 * Users
 */
class Users {
  constructor(http) {
    this.http = http;
    autoBind(this);
  }

  /**
   * @param {Object} bodyParams
   * @return {Promise}
   */
  createUser(bodyParams) {
    return this.http.post(_usersUri(), bodyParams);
  }

  /**
   * @param {string} userId
   * @return {Promise}
   */
  getUser(userId) {
    return this.http.get(_usersUri(userId));
  }

  /**
   * @param {string} userId
   * @param {Object} bodyParams
   * @return {Promise}
   */
  updateUser(userId, bodyParams) {
    return this.http.put(_usersUri(userId), bodyParams);
  }

  /**
   * @param {string} userId
   * @return {Promise}
   */
  deleteUser(userId) {
    return this.http.delete(_usersUri(userId));
  }

  /**
   * @param {Object} queryParams
   * @return {Promise}
   */
  listUsers(queryParams) {
    return this.http.get(_usersUri(), queryParams);
  }

  /**
   * @param {string} userId
   * @return {Promise}
   */
  createUserApiToken(userId) {
    return this.http.post(_apiTokenUri(userId));
  }

  /**
   * @param {string} userId
   * @return {Promise}
   */
  getUserApiToken(userId) {
    return this.http.get(_apiTokenUri(userId));
  }
}

function _usersUri(userId = '') {
  return `/users/${userId}`;
}

function _apiTokenUri(userId) {
  return `${_usersUri(userId)}/apitoken`;
}

module.exports = Users;
