const fetch = require('node-fetch');
const querystring = require('querystring');
const isEmpty = require('lodash.isempty');

class Http {
  constructor(config) {
    this.config = config;
  }

  get(uri, queryParams) {
    if (queryParams && !isEmpty(queryParams)) {
      uri += '?' + querystring.stringify(queryParams);
    }
    return this.fetchJsonWithAuth(uri, {method: 'GET'});
  }

  post(uri, body = {}) {
    return this.fetchJsonWithAuth(uri, {
      method: 'POST',
      body: JSON.stringify(body),
      headers: {'Content-Type': 'application/json'},
    });
  }

  put(uri, body) {
    return this.fetchJsonWithAuth(uri, {
      method: 'PUT',
      body: JSON.stringify(body),
      headers: {'Content-Type': 'application/json'},
    });
  }

  delete(uri, queryParams) {
    if (queryParams && !isEmpty(queryParams)) {
      uri += '?' + querystring.stringify(queryParams);
    }
    return this.fetchJsonWithAuth(uri, {method: 'DELETE'});
  }

  fetchJsonWithAuth(uri, options = {}) {
    options.headers = options.headers || {};
    options.headers.Accept = options.headers.Accept || 'application/json';
    return this.fetchWithAuth(uri, options)
      .then((response) => response.text())
      .then((text) => {
        try {
          return JSON.parse(text);
        } catch (error) {
          return text;
        }
      });
  }

  fetchWithAuth(uri, options = {}) {
    options.headers = options.headers || {};
    options.headers['X-API-Token'] = this.config.apiToken;
    options.headers['X-Powered-By'] = 'Qualtrics-SDK';
    return fetch(this.config.baseUrl + uri, options)
      .then(this._throwOnBadStatusCode);
  }

  _throwOnBadStatusCode(response) {
    if (!response.ok) {
      return response.text()
        .then((text) => {
          throw new Error(text);
        });
    } else {
      return response;
    }
  }
}

module.exports = Http;
